Skip to contents

Show methods for disords

Usage

# S4 method for class 'disord'
show(x)
disord_show(x)

Arguments

x

Object of class disord

Details

The print method simply prints the object's hash and its elements, together with a reminder that the elements are listed in an implementation-specific order. Function disord_show() is a helper function, not really intended for the end-user.

Author

Robin K. S. Hankin

Examples

print(rdis())
#> A disord object with hash af6a44adb9c53ebc0cc942ab995b31c91c7aa0ce and elements
#> [1] 4 1 9 2 7 3 8 3 1
#> (in some order)

a <- rdis()
print(a)
#> A disord object with hash 7df10f664e8a5776149760e3ef4d7d4dac6ae9fc and elements
#> [1] 1 9 5 2 8 2 4 5 7
#> (in some order)
print(a+100)  # same hash code
#> A disord object with hash 7df10f664e8a5776149760e3ef4d7d4dac6ae9fc and elements
#> [1] 101 109 105 102 108 102 104 105 107
#> (in some order)