Skip to contents

A summary method for disord objects, and a print method for summaries.

Usage

# S4 method for class 'disord'
summary(object, ...)
# S4 method for class 'disindex'
summary(object, ...)
# S3 method for class 'summary.disord'
print(x, ...)

Arguments

object,x

Object of class disord

...

Further arguments, currently ignored

Details

A summary.disord object is summary of a disord object x: a list with first element being the hash(x) and the second being summary(elements(x)). The print method is just a wrapper for this.

Author

Robin K. S. Hankin

Examples

summary(rdis(1000))
#> a disord object with hash c848d3e2d90e0dad8bb4eff9c3786ca8c09085bf 
#> 
#>    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#>     4.0   233.5   486.0   490.3   746.2   998.0